@@ -60,6 +60,7 @@ d_attribute_noreturn='undef'
 d_attribute_pure='undef'
 d_attribute_unused='undef'
 d_attribute_warn_unused_result='undef'
+d_backtrace='undef'
 d_bcmp='undef'
 d_bcopy='undef'
 d_bsd='undef'
@@ -97,6 +98,7 @@ d_difftime='undef'
 d_dir_dd_fd='undef'
 d_dirfd='undef'
 d_dirnamlen='undef'
+d_dladdr='undef'
 d_dlerror='undef'
 d_dlopen='undef'
 d_dlsymun='undef'
@@ -238,6 +240,7 @@ d_isnanl='undef'
 d_killpg='undef'
 d_lchown='undef'
 d_ldbl_dig='undef'
+d_ldexpl='undef'
 d_libm_lib_version='undef'
 d_link='undef'
 d_localtime64='undef'
@@ -311,6 +314,7 @@ d_pseudofork='undef'
 d_pthread_atfork='undef'
 d_pthread_attr_setscope='undef'
 d_pthread_yield='undef'
+d_ptrdiff_t='define'
 d_pwage='undef'
 d_pwchange='undef'
 d_pwclass='undef'
@@ -479,7 +483,9 @@ d_vprintf='define'
 d_vsnprintf='undef'
 d_wait4='undef'
 d_waitpid='undef'
+d_wcscmp='undef'
 d_wcstombs='undef'
+d_wcsxfrm='undef'
 d_wctomb='undef'
 d_writev='undef'
 d_xenix='undef'
@@ -547,12 +553,14 @@ i8size='1'
 i8type='signed char'
 i_arpainet='undef'
 i_assert='define'
+i_bfd='undef'
 i_bsdioctl=''
 i_crypt='undef'
 i_db='undef'
 i_dbm='undef'
 i_dirent='define'
 i_dlfcn='undef'
+i_execinfo='undef'
 i_fcntl='undef'
 i_float='undef'
 i_fp='undef'
@@ -641,6 +649,7 @@ ivsize='8'
 ivtype='long'
 lib_ext='.a'
 localtime_r_proto='0'
+longdblkind=0
 longdblsize=8
 longlongsize=8
 longsize='8'
@@ -776,6 +785,7 @@ uquadtype='unsigned long'
 use5005threads='undef'
 use64bitall='define'
 use64bitint='define'
+usecbacktrace='undef'
 usecrosscompile='undef'
 usedevel='undef'
 usedl='undef'
